import datetime
from typing import List, Optional
from pydantic import BaseModel

class ItemEntry(BaseModel):
    item_id: int
    name: str
    icon: str
    acs_slot: Optional[int]
    type: int
    active: int
    skin_id: Optional[int]
    updated_at: datetime.datetime


class ItemsResponse(BaseModel):
    total: int
    limit: int
    offset: int
    items: List[ItemEntry]


class ItemHistoryEntry(BaseModel):
    item_id: int
    action: str
    field_name: Optional[str]
    old_value: Optional[str]
    new_value: Optional[str]
    created_at: datetime.datetime


class ItemsHistoryResponse(BaseModel):
    total: int
    changes: List[ItemHistoryEntry]



from .base import RatingType, EstateType, EstateHistoryType, SSFont, ValidationError, HTTPValidationError, PunishType
from .server import (ServerStatusResponse, RatingResponse, EstateResponse, EstateHistoryResponse, MapResponse,
                     ServerOnlineHistoryResponse, AuctionInfo, Coordinates, HouseEntry, BusinessEntry,
                     EstateHistoryEntry, RatingPlayer, EXPCalcResponse, MapZonesResponse, MapZone, CurrencyResponse)
from .player import (CheckRpResponse, RpNickResponse, FindPlayerResponse, OnlineResponse,
                     NicknameHistoryEntry, MoneyHistoryEntry, PlayerViewsResponse, PlayerSessionsResponse,
                     PlayerCalendarResponse, PlayerGeneral, PlayerFraction, PlayerMoney, PlayerLvl,
                     PlayerPunishes, PlayerVIP, PlayerRatingEntry, AdminInfo, PlayerViewEntry, OnlineEntry,
                     PlayerSessionEntry, CalendarDayEntry, PrivacyToggleRequest, PunishHistoryResponse,
                     PunishHistoryEntry)
from .fraction import (MembersResponse, LeadersResponse, InterviewsResponse, PlayersResponse, MembersPlayer,
                      MembersRecord, LeaderEntry, InterviewEntry, PlayerEntry)
from .token import TokenResponse, RequestLogResponse, RequestStatsResponse, RequestLogEntry
from .ai import AIResponse
from .items import ItemsResponse, ItemEntry, ItemsHistoryResponse, ItemHistoryEntry
from .internal import (BotDetectionResponse, CheckRpManualOverridesListResponse, AdminsResponse, BotAccount, InterviewRequestEntry,
                       CheckrRpManualOverrideEntry, AdminEntry, FindStatsResponse, PunishRequest, CurrencyRequest,
                       FractionSalariesRequest, IngameMapData, IngameJudgeData, IngameLeaderData, IngameAdminData,
                       PlayerExtendedEntry, PlayersRequest, IngameInterviewData, IngameMemberEntry, RankSalaryEntry)



import datetime
from typing import List, Optional, Literal
from pydantic import BaseModel

class MembersPlayer(BaseModel):
    account_id: Optional[int]
    nickname: str
    is_online: bool
    is_leader: bool
    rank_number: int
    rank_label: Optional[str]
    ingame_id: Optional[int]
    nickname_color: Optional[int]


class MembersRecord(BaseModel):
    online_players: int
    leader_nickname: Optional[str]
    modified_at: Optional[datetime.datetime]
    modified_by: Literal["system", "admin"]


class MembersResponse(BaseModel):
    server_id: int
    fraction_id: int
    server_label: str
    fraction_label: str
    total_players: int
    total_online: int
    leader_nickname: Optional[str]
    is_leader_online: bool
    online_updated_at: datetime.datetime
    members_updated_at: datetime.datetime
    online_record: MembersRecord
    players: List[MembersPlayer]


class LeaderEntry(BaseModel):
    fraction_id: int
    fraction_label: str
    nickname: str
    ingame_id: int
    phone_number: Optional[int]
    afk: Optional[int]


class LeadersResponse(BaseModel):
    data: List[LeaderEntry]
    server_id: int
    server_label: str
    updated_at: datetime.datetime


class InterviewEntry(BaseModel):
    fraction_id: int
    fraction_label: str
    place: Optional[str]
    time: Optional[str]


class InterviewsResponse(BaseModel):
    server_id: int
    server_label: str
    data: List[InterviewEntry]
    updated_at: datetime.datetime


class PlayerEntry(BaseModel):
    color: int
    ping: int
    id: int
    lvl: int
    nickname: str


class PlayersResponse(BaseModel):
    server_id: int
    server_label: str
    players: List[PlayerEntry]
    updated_at: datetime.datetime



from enum import Enum
from typing import List, Union, Optional
from pydantic import BaseModel

class RatingType(str, Enum):
    ADMINS = "admins"
    ADVOCATES = "advocates"
    COMBINE_OPERATORS = "combine_operators"
    BUS_DRIVERS = "bus_drivers"
    TRACTOR_DRIVERS = "tractor_drivers"
    CATCHERS = "catchers"
    COLLECTORS = "collectors"
    CORN_PILOTS = "corn_pilots"
    CRYPTO_ASC = "crypto_asc"
    CRYPTO_BTC = "crypto_btc"
    ELECTRIC_TRAIN_DRIVERS = "electric_train_drivers"
    LVL_FAMILIES = "lvl_families"
    LVL_PLAYERS = "lvl_players"
    MECHANICS = "mechanics"
    RICHEST = "richest"
    OUTBIDS = "outbids"
    PILOTS = "pilots"
    SELLERS = "sellers"
    TAXI_DRIVERS = "taxi_drivers"
    TRAM_DRIVERS = "tram_drivers"
    TRUCKERS = "truckers"
    CLADMENS = "cladmens"


class EstateType(str, Enum):
    HOUSES = "houses"
    BUSINESSES = "businesses"


class EstateHistoryType(str, Enum):
    HOUSE = "house"
    BUSINESS = "business"


class PunishType(str, Enum):
    KICK = "kick"
    WARN = "warn"
    WARNOFF = "warnoff"
    JAIL = "jail"
    JAILOFF = "jailoff"
    MUTE = "mute"
    MUTEOFF = "muteoff"
    RMUTE = "rmute"
    BAN = "ban"
    BANIP = "banip"
    UNJAIL = "unjail"
    UNMUTE = "unmute"
    UNRMUTE = "unrmute"
    APUNISH = "apunish"
    APUNISHOFF = "apunishoff"
    UNAPUNISH = "unapunish"


class SSFont(str, Enum):
    ARIAL_BOLD = 'arialbd.ttf'
    ARIAL_BOLD_ITALIC = 'arialbdi.ttf'
    BITTER_BOLD = 'bitterbd.ttf'
    BITTER_BOLD_ITALIC = 'bitterbdi.ttf'
    MONTSERRAT_BOLD = 'montserratbd.ttf'
    MONTSERRAT_BOLD_ITALIC = 'montserratbdi.ttf'
    NUNITO_BOLD = 'nunitobd.ttf'
    NUNITO_BOLD_ITALIC = 'nunitobdi.ttf'
    OPENSANS_BOLD = 'opensansbd.ttf'
    OPENSANS_BOLD_ITALIC = 'opensansbdi.ttf'
    UBUNTU_BOLD = 'ubuntubd.ttf'
    UBUNTU_BOLD_ITALIC = 'ubuntubdi.ttf'
    ROBOTO_BOLD = 'robotobd.ttf'
    ROBOTO_BOLD_ITALIC = 'robotobdi.ttf'
    SF_PRO_DISPLAY_BOLD = 'SF-Pro-Display-Bold.otf'


class ValidationError(BaseModel):
    loc: List[Union[str, int]]
    msg: str
    type: str


class HTTPValidationError(BaseModel):
    detail: Optional[List[ValidationError]] = None
